import { IMessageDefinition } from "@zowe/imperative";
/**
 * Constants for provisioning related info.
 * @export
 * @class ProvisioningConstants
 */
export declare class ProvisioningConstants {
    /**
     * URI base for provisioning API.
     * @static
     * @type {string}
     * @memberof ProvisioningConstants
     */
    static readonly RESOURCE: string;
    /**
     * URI base for provisioned instances API.
     * @static
     * @type {string}
     * @memberof ProvisioningConstants
     */
    static readonly INSTANCES_RESOURCE: string;
    /**
     * URI base for published templates API.
     * @static
     * @type {string}
     * @memberof ProvisioningConstants
     */
    static readonly TEMPLATES_RESOURCES: string;
    /**
     * URI base for performed actions on a provisioned instance.
     * @static
     * @type {string}
     * @memberof ProvisioningConstants
     */
    static readonly ACTIONS_RESOURCES: string;
    /**
     * URI base for provisioned instance variables.
     * @static
     * @type {string}
     * @memberof ProvisioningConstants
     */
    static readonly VARIABLES_RESOURCE: string;
    /**
     * Parameter for filtering by type.
     * @static
     * @type {string}
     * @memberof ProvisioningConstants
     */
    static readonly RESOURCE_TYPE: string;
    /**
     * Parameter for filtering by external name.
     * @static
     * @type {string}
     * @memberof ProvisioningConstants
     */
    static readonly RESOURCE_EXTERNAL_NAME: string;
    /**
     * URI base for provisioning a published template.
     * @static
     * @type {string}
     * @memberof ProvisioningConstants
     */
    static readonly RESOURCE_PROVISION_RUN: string;
    /**
     * Version of the z/OSMF software services template service
     * @static
     * @type {string}
     * @memberOf ProvisioningConstants
     */
    static readonly ZOSMF_VERSION: string;
}
/**
 * Error message that no session provided.
 * @static
 * @type {IMessageDefinition}
 * @memberof ProvisioningConstants
 */
export declare const noSessionProvisioning: IMessageDefinition;
/**
 * Error message that no z/OSMF version parameter string was supplied.
 * @static
 * @type {IMessageDefinition}
 * @memberof ProvisioningConstants
 */
export declare const nozOSMFVersion: IMessageDefinition;
/**
 * Error message that no template name parameter string was supplied.
 * @static
 * @type {IMessageDefinition}
 * @memberof ProvisioningConstants
 */
export declare const noTemplateName: IMessageDefinition;
/**
 * No account number was provided error message.
 * @static
 * @type {IMessageDefinition}
 * @memberof ProvisioningConstants
 */
export declare const noAccountInfo: IMessageDefinition;
/**
 * Error message that no instance-id parameter string was supplied.
 * @static
 * @type {IMessageDefinition}
 * @memberof ProvisioningConstants
 */
export declare const noInstanceId: IMessageDefinition;
/**
 * Error message that no template name parameter string was supplied.
 * @static
 * @type {IMessageDefinition}
 * @memberof ProvisioningConstants
 */
export declare const noActionName: IMessageDefinition;
