"use strict";
/*!
 * This program and the accompanying materials are made available under the terms of the
 * Eclipse Public License v2.0 which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-v20.html
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Copyright Contributors to the Zowe Project.
 *
 */
Object.defineProperty(exports, "__esModule", { value: true });
const PerformanceApiError_1 = require("./PerformanceApiError");
/**
 * Thrown when a function timer was removed that was never added.
 *
 * @external
 *
 * @example
 * function bad() {
 *   // Does stuff
 * }
 *
 * bad = PerfTiming.api.unwatch(bad);
 */
class TimerDoesNotExistError extends PerformanceApiError_1.PerformanceApiError {
    /**
     * Construct the error object with a specific message.
     * @param name The name of the timer that was not found.
     */
    constructor(name) {
        super(`A function timer with the name "${name}", does not exist. Please create the timer first.`);
    }
}
exports.TimerDoesNotExistError = TimerDoesNotExistError;
//# sourceMappingURL=TimerDoesNotExistError.js.map