"use strict";
/*
* This program and the accompanying materials are made available under the terms of the *
* Eclipse Public License v2.0 which accompanies this distribution, and is available at *
* https://www.eclipse.org/legal/epl-v20.html                                      *
*                                                                                 *
* SPDX-License-Identifier: EPL-2.0                                                *
*                                                                                 *
* Copyright Contributors to the Zowe Project.                                     *
*                                                                                 *
*/
Object.defineProperty(exports, "__esModule", { value: true });
var MessageCategoryId;
(function (MessageCategoryId) {
    MessageCategoryId["dataset"] = "dataset";
    MessageCategoryId["datasetMember"] = "datasetMember";
})(MessageCategoryId = exports.MessageCategoryId || (exports.MessageCategoryId = {}));
var MessageHierarchyType;
(function (MessageHierarchyType) {
    MessageHierarchyType["generic"] = "generic";
    MessageHierarchyType["specific"] = "specific";
})(MessageHierarchyType = exports.MessageHierarchyType || (exports.MessageHierarchyType = {}));
var MessageContentType;
(function (MessageContentType) {
    MessageContentType["open"] = "open";
    MessageContentType["upload"] = "upload";
})(MessageContentType = exports.MessageContentType || (exports.MessageContentType = {}));
const items = [
    require("./items/dataset"),
    require("./items/datasetMember")
].map((item) => item.default);
function mergeMessages(generic, specific) {
    if (generic) {
        const result = Object.assign({}, generic);
        if (specific) {
            for (const key in specific) {
                if (specific.hasOwnProperty(key)) {
                    result[key] = specific[key];
                }
            }
        }
        return result;
    }
    return specific;
}
function getMessageById(id, type) {
    const targetItem = items.find((item) => item.id === id);
    if (targetItem) {
        const messages = mergeMessages(targetItem.generic && targetItem.generic.messages, targetItem.messages);
        return messages[type] || null;
    }
    return null;
}
exports.getMessageById = getMessageById;
function getMessageByNode(node, type) {
    const targetItems = items.filter((item) => item.check(node));
    let targetItem;
    if (targetItems.some((item) => item.type === MessageHierarchyType.specific)) {
        targetItem = targetItems.filter((item) => item.type === MessageHierarchyType.specific).pop();
    }
    else {
        targetItem = targetItems.pop();
    }
    if (targetItem) {
        const messages = mergeMessages(targetItem.generic && targetItem.generic.messages, targetItem.messages);
        return messages[type] || null;
    }
    return null;
}
exports.getMessageByNode = getMessageByNode;

//# sourceMappingURL=index.js.map
